Type: Package
Package: easystats
Title: Framework for Easy Statistical Modeling, Visualization, and
        Reporting
Version: 0.7.6
Authors@R: 
    c(person(given = "Daniel",
             family = "Lüdecke",
             role = c("aut", "cre"),
             email = "d.luedecke@uke.de",
             comment = c(ORCID = "0000-0002-8895-3206")),
      person(given = "Dominique",
             family = "Makowski",
             role = "aut",
             email = "dom.makowski@gmail.com",
             comment = c(ORCID = "0000-0001-5375-9967")),
      person(given = "Mattan S.",
             family = "Ben-Shachar",
             role = "aut",
             email = "matanshm@post.bgu.ac.il",
             comment = c(ORCID = "0000-0002-4287-4801")),
      person(given = "Indrajeet",
             family = "Patil",
             role = "aut",
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531")),
      person(given = "Brenton M.",
             family = "Wiernik",
             role = "aut",
             email = "brenton@wiernik.org",
             comment = c(ORCID = "0000-0001-9560-6336")),
      person("Etienne", "Bacher", , "etienne.bacher@protonmail.com", role = "aut",
             comment = c(ORCID = "0000-0002-9271-5075")),
      person(given = "Rémi",
             family = "Thériault",
             role = "aut",
             email = "remi.theriault@mail.mcgill.ca",
             comment = c(ORCID = "0000-0003-4315-6788")))
Maintainer: Daniel Lüdecke <d.luedecke@uke.de>
Description: A meta-package that installs and loads a set of packages from
    'easystats' ecosystem in a single step. This collection of packages provide
    a unifying and consistent framework for statistical modeling, visualization,
    and reporting. Additionally, it provides articles targeted at instructors for
    teaching 'easystats', and a dashboard targeted at new R users for easily
    conducting statistical analysis by accessing summary results, model fit indices,
    and visualizations with minimal programming.
License: MIT + file LICENSE
URL: https://easystats.github.io/easystats/
BugReports: https://github.com/easystats/easystats/issues
Depends: R (>= 3.6)
Imports: bayestestR (>= 0.16.1), correlation (>= 0.8.8), datawizard (>=
        1.1.0), effectsize (>= 1.0.1), insight (>= 1.3.1), modelbased
        (>= 0.12.0), parameters (>= 0.27.0), performance (>= 0.15.0),
        report (>= 0.6.1), see (>= 0.11.0), tools, utils
Suggests: callr, collapse, cranlogs, DHARMa, DT, flexdashboard (>=
        0.6.2), Formula, ggplot2, glmmTMB, httr, jsonlite, knitr,
        marginaleffects (>= 0.25.0), mockery, pak, patchwork, scholar,
        rmarkdown, testthat (>= 3.2.1), withr, xml2
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Config/Needs/website: easystats/easystatstemplate
NeedsCompilation: no
Packaged: 2026-05-24 17:03:34 UTC; DL
Author: Daniel Lüdecke [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8895-3206>),
  Dominique Makowski [aut] (ORCID:
    <https://orcid.org/0000-0001-5375-9967>),
  Mattan S. Ben-Shachar [aut] (ORCID:
    <https://orcid.org/0000-0002-4287-4801>),
  Indrajeet Patil [aut] (ORCID: <https://orcid.org/0000-0003-1995-6531>),
  Brenton M. Wiernik [aut] (ORCID:
    <https://orcid.org/0000-0001-9560-6336>),
  Etienne Bacher [aut] (ORCID: <https://orcid.org/0000-0002-9271-5075>),
  Rémi Thériault [aut] (ORCID: <https://orcid.org/0000-0003-4315-6788>)
Repository: CRAN
Date/Publication: 2026-05-24 19:10:02 UTC
Built: R 4.5.2; ; 2026-05-25 02:36:59 UTC; unix
