# Generated by roxygen2: do not edit by hand

S3method(display,easystats_cites)
S3method(display,easystats_downloads)
S3method(print,easystats_cites)
S3method(print,easystats_downloads)
S3method(print_html,easystats_cites)
S3method(print_html,easystats_downloads)
S3method(print_md,easystats_cites)
S3method(print_md,easystats_downloads)
export(display)
export(easystats_citations)
export(easystats_downloads)
export(easystats_packages)
export(easystats_update)
export(easystats_zen)
export(install_latest)
export(install_suggested)
export(model_dashboard)
export(print_html)
export(print_md)
export(show_reverse_dependencies)
export(show_suggested)
importFrom(insight,display)
importFrom(insight,print_html)
importFrom(insight,print_md)
